#*****************************************************************************

#                      IPG Converter Version 0.5

#

#           Python script for IPG Data Conversion and Analysis 

#              written by Mark S. Adams, Cisco Lawrenceville

#

#                  Copyright 2011, Cisco Systems, Inc.

#

#                     Proprietary and Confidential

#         Unauthorized distribution or copying is prohibited

#                          All rights reserved

#

# No part of this computer software may be reprinted, reproduced or utilized

# in any form or by any electronic, mechanical, or other means, now known or

# hereafter invented, including photocopying and recording, or using any

# information storage and retrieval system, without permission in writing

# from Cisco Systems, Inc.

#*****************************************************************************



import os

import sys



import ipg_converter_cli

from pytronix.lib.gui  import PytronixGui as Gui

from pytronix.lib.gui  import PytronixGuiBoard_Type1 as Board



class MainBoard( Board.PytronixGuiBoard_MainAbstract ):

    def __init__(self, base_board):

        Board.PytronixGuiBoard_MainAbstract.__init__(self,base_board)

        self.update_settings({

            self.tMainButtonSizeX : 4,

            self.tMainButtonSizeY : 5,

            self.tMainViewSizeZ   : 1,

            self.tMainTitle       : 'IPG Converter ver. %s'%(ipg_converter_cli.Version),

            self.tMainSize        : (900, 590),

            self.tMainViewSizeZ   : 1,

            })



class ListBoard_1( Board.PytronixGuiBoard_ListDirectory ):

    def __init__(self, base_board):

        Board.PytronixGuiBoard_ListDirectory.__init__(self,base_board)



class ListBoard_2( Board.PytronixGuiBoard_ListDirectory ):

    def __init__(self, base_board):

        Board.PytronixGuiBoard_ListDirectory.__init__(self,base_board)







class ViewBoard_1( Board.PytronixGuiBoard_ViewAbstract ):

    def __init__(self, base_board):

        Board.PytronixGuiBoard_ViewAbstract.__init__(self,base_board)

        self.update_settings({

            self.tViewDualListsOn         : True,

            self.tViewDualListsProportion : [50,50],

            })

        self.header = 'Main'

               

    def build_buttons(self, buttons):



        buttons[ 0][ 0].label = 'Overlap: Run Analysis ...'

        buttons[ 0][ 0].function = app_obj.fun_overlap_run_analysis

        buttons[ 0][ 1].label = 'Overlap: See Messages'

        buttons[ 0][ 1].function = app_obj.fun_overlap_see_messages

        buttons[ 0][ 2].label = 'Overlap: Save Messages'

        buttons[ 0][ 2].function = app_obj.fun_overlap_save_messages

        buttons[ 0][ 3].label = 'Clear bottom output'

        buttons[ 0][ 3].function = app_obj.fun_clear_bottom_output        

        buttons[ 0][ 4].label = 'Configure: Editor'

        buttons[ 0][ 4].function = app_obj.fun_configure_editor        

        

        buttons[ 1][ 0].label = 'Convert Cisco to Videotron =>'

        buttons[ 1][ 0].function = app_obj.fun_conversion_cisco_to_videotron

        buttons[ 1][ 1].label = 'Conversion: See Messages'

        buttons[ 1][ 1].function = app_obj.fun_conversion_see_messages

        buttons[ 1][ 2].label = 'Un GZip to Text File'

        buttons[ 1][ 2].function = app_obj.fun_ungz_file

        buttons[ 1][ 3].label = 'GZip a Text File'

        buttons[ 1][ 3].function = app_obj.fun_gz_file

        buttons[ 1][ 4].label = 'Configure: Set Cisco Dir.'

        buttons[ 1][ 4].function = app_obj.fun_set_dir_cisco

        

        buttons[ 2][ 0].label = 'Web Help'

        buttons[ 2][ 0].function = app_obj.fun_help

        buttons[ 2][ 1].label = 'Conversion: Save Messages'

        buttons[ 2][ 1].function = app_obj.fun_conversion_save_messages

        buttons[ 2][ 2].label = 'Zip extract all'

        buttons[ 2][ 2].function = app_obj.fun_unzip_file

        buttons[ 2][ 3].label = 'Zip a group of files'

        buttons[ 2][ 3].function = app_obj.fun_zip_file

        buttons[ 2][ 4].label = 'Configure: Set Videotron Dir.'

        buttons[ 2][ 4].function = app_obj.fun_set_dir_videotron



        buttons[ 3][ 0].label = 'Edit a File'

        buttons[ 3][ 0].function = app_obj.fun_edit_file

        buttons[ 3][ 1].label = 'Rename a File'

        buttons[ 3][ 1].function = app_obj.fun_rename_file

        buttons[ 3][ 2].label = 'Refresh Lists'

        buttons[ 3][ 2].function = app_obj.fun_refresh_lists

        buttons[ 3][ 3].label = 'Copy a File'

        buttons[ 3][ 3].function = app_obj.fun_copy_file

        buttons[ 3][ 4].label = 'Delete File(s)'

        buttons[ 3][ 4].function = app_obj.fun_delete_file





        notes = '''

        buttons[ 3][ 3].label = 'Test Mode - Quick Convert'

        buttons[ 3][ 3].function = app_obj.fun_test_mode_quick

        buttons[ 3][ 3].label = 'Test 1'

        buttons[ 3][ 3].function = app_obj.fun_test1

        buttons[ 3][ 4].label = 'Test 2'

        buttons[ 3][ 4].function = app_obj.fun_test2

        '''





def make_base_board(app, log_in):

    global log

    global app_obj

    global base_board

    global main_board

    log = log_in

    app_obj = app

    base_board    = Board.PytronixGuiBoard_Type1(log)

    main_board   = MainBoard(base_board)

    view_board_1 = ViewBoard_1(base_board)

    view_boards = [

        view_board_1,

        ]

    base_board.set_data_objs(main_board, view_boards)

    list_board_1 = ListBoard_1(base_board)

    list_board_2 = ListBoard_2(base_board)

    view_board_1.list_1 = list_board_1

    view_board_1.list_2 = list_board_2 

    base_board.make_gui()

    return base_board   



def launch_gui():

    base_board.launch_gui()





