import os
import sys
import logging
#import time
#import re
import json
from types import *



from pytronix.lib.general import Tags
from pytronix.lib.general import Singleton
#from pytronix.lib.general import NullLogHandler
log = None

def get_name_no_extension( name ):
    name_no_extension = name
    parts = name.split('.')
    if len(parts) == 2:
        name_no_extension = parts[0]
    if  len(parts) > 2:
        name_no_extension = '.'.join(parts[0:-1])
    return name_no_extension

def get_extension( name ):
    extension = ''
    parts = name.split('.')
    if  len(parts) > 1:
        extension = parts[-1]
    return extension


class FilelodLocator (object):
    __metaclass__ = Singleton.Singleton

    def __init__ (self, file, log_in=0):
        global log
        if 'true_flag' in self.__dict__:
            # Second or more call to Singleton, no need to initialize.
            return
        if log_in:
            log = log_in
        elif not log:
            log = logging.getLogger("Filelod Locator")
            # Nullify if you want no verbose
            #log.addHandler(NullLogHandler.NullLogHandler())
        self.true_flag = True
        parts = os.path.split(file)
        self.local_path = parts[0]
        self.local_name = parts[1]
        self.local_name_no_extension = get_name_no_extension(self.local_name)
        
        
        # For now...
        self.auto_path  = self.local_path

    def get_name_with_no_extension(self, name ):
        return( get_name_no_extension(name))
    
    def get_auto_path(self):
        return self.auto_path
    
    
class Filelod (object):

    def __init__ (self, log_in=0):
        global log
        if log_in:
            self.log = log = log_in
        elif not log:
            self.log = log = logging.getLogger("Filelod")
            # Nullify if you want no verbose
            #log.addHandler(NullLogHandler.NullLogHandler())
        self.tags  = [
            'tFilelodIndex',
            'tFilelodRank',
            'tFilelodFindRank',
            'tFilelodFindTag',
            'tFilelodFindValue',
            'tFilelodFindIndex',
            'tFilelodAutoSaveOn',
            ]
        Tags.add_tags_as_attributes( self, self.tags )
        self.settings = {}
        self.default_settings = {
            self.tFilelodAutoSaveOn:1,
            }
        self.update_settings(self.default_settings)
        self.dictionary_list = []
        self.file_path_only = 0
        self.file_name_only = 0
        self.filename       = 0
        self.file_in_sync   = False
        self.filelod_locator = FilelodLocator()
        

    def update_settings(self, data):
        self.settings.update(data)
        

    def add_tags(self, tags):
        Tags.add_tags_as_attributes( self, tags )
        self.tags += tags


    def set_full_filename(self, filename):
        self.filename = filename
        parts = os.path.split(self.filename)
        self.file_path_only = parts[0]
        self.file_name_only = parts[1]


    def  set_file_name_only(self, name):
        self.file_name_only = name


    def  set_file_path_only(self, path):
        self.file_path_only = path


    def make_filename(self):
        if not self.file_path_only:
            self.file_path_only = self.filelod_locator.get_auto_path()
        if not self.file_path_only:
            self.log.error('file path not defined')
            return 1 
        if not self.file_name_only:
            self.log.error('file name not defined')
            return 2
        self.filename = os.path.join(self.file_path_only, self.file_name_only)
        return(0)


    def auto_save_file(self):
        if self.settings.get(self.tFilelodAutoSaveOn, 0) and not self.file_in_sync:
            self.save_file()


    def save_file(self):
        if self.make_filename():
            return 1 
        outfile = open( self.filename, 'w')
        if not outfile:
            self.log.error('File error %s: %s'%(sys.exc_info()[0], self.filename))
            return 2
        outfile.write( json.dumps(self.dictionary_list, sort_keys=True, indent=4) )
        outfile.close()
        self.file_in_sync = True
        return 0
    
    def exists(self):
        if self.make_filename():
            return(0)
        return( os.path.exists(self.filename))

    
    def erLoadFile(self):
        if self.make_filename():
            return(1,0)
        if not os.path.exists(self.filename):
            self.log.error('File, %s, does not exist'%(self.filename))
            return(2,0)
        infile = open( self.filename, 'r')
        if not infile:
            self.log.error('File error %s: %s'%(sys.exc_info()[0], self.filename))
            return(3,0)
        jobj = json.load(infile)
        infile.close()
        errors = self.check_dictionary_list_as_valid(jobj)
        if len(errors):
            for error in errors:
                self.log.error('Error: %s'%(error))
            return(4,0)
        self.dictionary_list = jobj
        return( 0, self.dictionary_list )


    def check_dictionary_list_as_valid(self, lod_in):
        errors = []
        if type(lod_in) != ListType:
            errors.append('Dictionary list not a list, a %s'%type(lod_in))
            return errors
        for i, item in enumerate( lod_in):
            if type(item) != DictType:
                errors.append('Dictionary list item %d not a dict, a %s: %s'%(i, type(item),str(item)))
            else:
                # ToDo: check dict if all strings
                pass
        return errors
    
    def make_lod_copy(self, lod_in):
        lod_out = []
        for diction in lod_in:
            lod_out.append(diction.copy())
        return lod_out
    

    def print_errors(self, errors ):
        for error in errors:
            self.log.error('Error: %s'%(error))
            
            
    def set_dictionary_list(self, lod_in):
        errors = self.check_dictionary_list_as_valid(lod_in)
        if len(errors):
            for error in errors:
                self.log.error('Error: %s'%(error))
            return 1
        #self.dictionary_list = self.make_lod_copy(lod_in)
        self.dictionary_list = lod_in
        self.file_in_sync   = False
        return 0
    
    def get_item(self, lod_access, verbose=0 ):
        indexor = lod_access.get(self.tFilelodIndex, -1)
        tag     = lod_access.get(self.tFilelodFindTag, '')
        if verbose:
            self.log.info('indexor(%d) tag(%s):'%(indexor, tag))
        if  indexor >= 0 and indexor < len(self.dictionary_list) and tag:
            return( self.dictionary_list[indexor].get(tag, '' ))
        return ''


    def set_item(self, lod_access, value, save=0, verbose=0 ):
        indexor = lod_access.get(self.tFilelodIndex, -1)
        tag     = lod_access.get(self.tFilelodFindTag, '')
        if verbose:
            self.log.info('indexor(%d) tag(%s):'%(indexor, tag))
        if  indexor >= 0 and indexor < len(self.dictionary_list) and tag:
            self.dictionary_list[indexor][tag] = value
            self.file_in_sync   = False
            if save:
                self.save_file()
            return 0            
        return 1

